@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #ifndef DIAGRAMSETTINGS_H
@@ -31,7 +31,7 @@ class DiagramSettings : public QWidget
     Q_OBJECT
 
 public:
-    explicit DiagramSettings( KChart::Chart* chart, QWidget *parent = nullptr );
+    explicit DiagramSettings( KChart::Chart* chart, QWidget *parent = 0 );
     ~DiagramSettings();
 
 public Q_SLOTS:
