@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "mainwindow.h"
@@ -23,27 +23,16 @@
 
 class TestDrawIntoPainter: public QObject {
     Q_OBJECT
-private Q_SLOTS:
-
-  void initTestCase()
-  {
-    qputenv("QTEST_FUNCTION_TIMEOUT", QByteArray("600000"));
-  }
+private slots:
 
   void testOriginal()
   {
-    mainWindow.updateData(QStringLiteral(":/original"));
+    mainWindow.updateData(tr(":/original"));
   }
 
   void testTest()
   {
-    // The test in :/test is so large it times out on CI
-    // so we run the half sized :/test4000 for now
-#if 0
-    mainWindow.updateData(QStringLiteral(":/test"));
-#else
-    mainWindow.updateData(QStringLiteral(":/test_small"));
-#endif
+    mainWindow.updateData(tr(":/test"));
   }
 
 private:
