@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -47,7 +47,7 @@ namespace KChart {
 /**
  * \internal
  */
-class AbstractCartesianDiagram::Private : public AbstractDiagram::Private
+class Q_DECL_HIDDEN AbstractCartesianDiagram::Private : public AbstractDiagram::Private
 {
     friend class AbstractCartesianDiagram;
 public:
@@ -64,9 +64,9 @@ public:
         }
 
     /** \reimpl */
-    virtual CartesianDiagramDataCompressor::AggregatedDataValueAttributes aggregatedAttrs(
+    CartesianDiagramDataCompressor::AggregatedDataValueAttributes aggregatedAttrs(
             const QModelIndex & index,
-            const CartesianDiagramDataCompressor::CachePosition * position ) const
+            const CartesianDiagramDataCompressor::CachePosition * position ) const Q_DECL_OVERRIDE
     {
         if ( position )
             return compressor.aggregatedAttrs( diagram, index, *position );
