@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -42,7 +42,7 @@ namespace KChart {
 /**
   * \internal
   */
-class CartesianAxis::Private : public AbstractAxis::Private
+class Q_DECL_HIDDEN CartesianAxis::Private : public AbstractAxis::Private
 {
     friend class CartesianAxis;
 
