@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -46,7 +46,7 @@ namespace KChart {
      * \internal
      */
 
-    class LeveyJenningsCoordinatePlane::Private : public CartesianCoordinatePlane::Private
+    class Q_DECL_HIDDEN LeveyJenningsCoordinatePlane::Private : public CartesianCoordinatePlane::Private
     {
         friend class LeveyJenningsCoordinatePlane;
 
@@ -57,7 +57,7 @@ namespace KChart {
             // grid is delete in base class dtor
         }
 
-        virtual void initialize()
+        void initialize() Q_DECL_OVERRIDE
         {
             grid = new LeveyJenningsGrid();
         }
