@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -29,7 +29,7 @@
 
 using namespace KChart;
 
-class LeveyJenningsGridAttributes::Private
+class Q_DECL_HIDDEN LeveyJenningsGridAttributes::Private
 {
     friend class LeveyJenningsGridAttributes;
 public:
