@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -42,6 +42,7 @@ Plotter::Private::~Private()
 {
     delete normalPlotter;
     delete percentPlotter;
+    delete stackedPlotter;
 }
 
 
