@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartPlotterDiagramCompressor.h"
@@ -22,7 +22,7 @@
 #include "KChartPlotterDiagramCompressor_p.h"
 #include "KChartMath_p.h"
 
-#include <QPointF>
+#include <QtCore/QPointF>
 
 using namespace KChart;
 
@@ -88,7 +88,7 @@ PlotterDiagramCompressor::Iterator::~Iterator()
 
 bool PlotterDiagramCompressor::Iterator::isValid() const
 {
-    if ( m_parent == nullptr )
+    if ( m_parent == 0 )
         return false;
     return m_dataset >= 0 && m_index >= 0 && m_parent.data()->rowCount() > m_index;
 }
@@ -409,7 +409,7 @@ void PlotterDiagramCompressor::Iterator::invalidate()
 
 PlotterDiagramCompressor::Private::Private( PlotterDiagramCompressor *parent )
     : m_parent( parent )
-    , m_model( nullptr )
+    , m_model( 0 )
     , m_mergeRadius( 0.1 )
     , m_maxSlopeRadius( 0.1 )
     , m_boundary( qMakePair( QPointF( std::numeric_limits<qreal>::quiet_NaN(), std::numeric_limits<qreal>::quiet_NaN() )
@@ -423,7 +423,7 @@ PlotterDiagramCompressor::Private::Private( PlotterDiagramCompressor *parent )
 
 void PlotterDiagramCompressor::Private::setModelToZero()
 {
-    m_model = nullptr;
+    m_model = 0;
 }
 
 inline bool inBoundary( const QPair< qreal, qreal > &bounds, qreal value )
@@ -444,125 +444,123 @@ bool PlotterDiagramCompressor::Private::inBoundaries( Qt::Orientation orient, co
     return true;
 }
 
-#if 0
-// TODO this is not threadsafe do never try to invoke the painting in a different thread than this
-// method
-void PlotterDiagramCompressor::Private::rowsInserted( const QModelIndex& /*parent*/, int start, int end )
-{
+//// TODO this is not threadsafe do never try to invoke the painting in a different thread than this
+//// method
+//void PlotterDiagramCompressor::Private::rowsInserted( const QModelIndex& /*parent*/, int start, int end )
+//{
 
-   if ( m_bufferlist.count() > 0 && !m_bufferlist[ 0 ].isEmpty() && start < m_bufferlist[ 0 ].count() )
-   {
-       calculateDataBoundaries();
-       clearBuffer();
-       return;
-   }
-   // we are handling appends only here, a prepend might be added, insert is expensive if not needed
-   qreal minX = std::numeric_limits< qreal >::max();
-   qreal minY = std::numeric_limits< qreal >::max();
-   qreal maxX = std::numeric_limits< qreal >::min();
-   qreal maxY = std::numeric_limits< qreal >::min();
-   for ( int dataset = 0; dataset < m_bufferlist.size(); ++dataset )
-   {
-       PlotterDiagramCompressor::DataPoint predecessor = m_bufferlist[ dataset ].isEmpty() ? DataPoint() : m_bufferlist[ dataset ].last();
+//    if ( m_bufferlist.count() > 0 && !m_bufferlist[ 0 ].isEmpty() && start < m_bufferlist[ 0 ].count() )
+//    {
+//        calculateDataBoundaries();
+//        clearBuffer();
+//        return;
+//    }
+//    // we are handling appends only here, a prepend might be added, insert is expensive if not needed
+//    qreal minX = std::numeric_limits< qreal >::max();
+//    qreal minY = std::numeric_limits< qreal >::max();
+//    qreal maxX = std::numeric_limits< qreal >::min();
+//    qreal maxY = std::numeric_limits< qreal >::min();
+//    for ( int dataset = 0; dataset < m_bufferlist.size(); ++dataset )
+//    {
+//        PlotterDiagramCompressor::DataPoint predecessor = m_bufferlist[ dataset ].isEmpty() ? DataPoint() : m_bufferlist[ dataset ].last();
 
-       qreal oldSlope = 0;
-       qreal newSlope = 0;
-       PlotterDiagramCompressor::DataPoint newdp = m_parent->data( CachePosition( start, dataset ) );
-       PlotterDiagramCompressor::DataPoint olddp = PlotterDiagramCompressor::DataPoint();
-       const int datacount = m_bufferlist[ dataset ].count();
-       if ( m_mode != PlotterDiagramCompressor::DISTANCE && m_bufferlist[ dataset ].count() > 1 )
-       {
-           oldSlope = calculateSlope( m_bufferlist[ dataset ][ datacount - 2 ], m_bufferlist[ dataset ][ datacount - 1 ] );
-           newSlope = calculateSlope( m_bufferlist[ dataset ][ datacount - 1 ], newdp );
-       }
-       bool first = true;
-       for ( int row = start; row <= end; ++row )
-       {
-           PlotterDiagramCompressor::DataPoint curdp = m_parent->data( CachePosition( row, dataset ) );
-           const bool checkcur = inBoundaries( Qt::Vertical, curdp ) && inBoundaries( Qt::Horizontal, curdp );
-           const bool checkpred = inBoundaries( Qt::Vertical, predecessor ) && inBoundaries( Qt::Horizontal, predecessor );
-           const bool check = checkcur || checkpred;
-           switch ( m_mode )
-           {
-           case( PlotterDiagramCompressor::BOTH ):
-               {
-                   if ( predecessor.distance( curdp ) > m_mergeRadius && check )
-                   {
-                       if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].append( curdp );
-                       }
-                       else if ( !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].insert( row, curdp );
-                       }
-                       predecessor = curdp;
-                       minX = qMin( curdp.key, m_boundary.first.x() );
-                       minY = qMin( curdp.value, m_boundary.first.y() );
-                       maxX = qMax( curdp.key, m_boundary.second.x() );
-                       maxY = qMax( curdp.value, m_boundary.second.y() );
-                   }
-               }
-               break;
-           case ( PlotterDiagramCompressor::DISTANCE ):
-               {
-                   if ( predecessor.distance( curdp ) > m_mergeRadius && check )
-                   {
-                       if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].append( curdp );
-                       }
-                       else if ( !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].insert( row, curdp );
-                       }
-                       predecessor = curdp;
-                       minX = qMin( curdp.key, m_boundary.first.x() );
-                       minY = qMin( curdp.value, m_boundary.first.y() );
-                       maxX = qMax( curdp.key, m_boundary.second.x() );
-                       maxY = qMax( curdp.value, m_boundary.second.y() );
-                   }
-               }
-               break;
-           case( PlotterDiagramCompressor::SLOPE ):
-               {
-                   if ( check && qAbs( newSlope - oldSlope ) >= m_maxSlopeRadius )
-                   {
-                       if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].append( curdp );
-                           oldSlope = newSlope;
-                       }
-                       else if ( !m_bufferlist[ dataset ].isEmpty() )
-                       {
-                           m_bufferlist[ dataset ].insert( row, curdp );
-                           oldSlope = newSlope;
-                       }
+//        qreal oldSlope = 0;
+//        qreal newSlope = 0;
+//        PlotterDiagramCompressor::DataPoint newdp = m_parent->data( CachePosition( start, dataset ) );
+//        PlotterDiagramCompressor::DataPoint olddp = PlotterDiagramCompressor::DataPoint();
+//        const int datacount = m_bufferlist[ dataset ].count();
+//        if ( m_mode != PlotterDiagramCompressor::DISTANCE && m_bufferlist[ dataset ].count() > 1 )
+//        {
+//            oldSlope = calculateSlope( m_bufferlist[ dataset ][ datacount - 2 ], m_bufferlist[ dataset ][ datacount - 1 ] );
+//            newSlope = calculateSlope( m_bufferlist[ dataset ][ datacount - 1 ], newdp );
+//        }
+//        bool first = true;
+//        for ( int row = start; row <= end; ++row )
+//        {
+//            PlotterDiagramCompressor::DataPoint curdp = m_parent->data( CachePosition( row, dataset ) );
+//            const bool checkcur = inBoundaries( Qt::Vertical, curdp ) && inBoundaries( Qt::Horizontal, curdp );
+//            const bool checkpred = inBoundaries( Qt::Vertical, predecessor ) && inBoundaries( Qt::Horizontal, predecessor );
+//            const bool check = checkcur || checkpred;
+//            switch ( m_mode )
+//            {
+//            case( PlotterDiagramCompressor::BOTH ):
+//                {
+//                    if ( predecessor.distance( curdp ) > m_mergeRadius && check )
+//                    {
+//                        if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].append( curdp );
+//                        }
+//                        else if ( !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].insert( row, curdp );
+//                        }
+//                        predecessor = curdp;
+//                        minX = qMin( curdp.key, m_boundary.first.x() );
+//                        minY = qMin( curdp.value, m_boundary.first.y() );
+//                        maxX = qMax( curdp.key, m_boundary.second.x() );
+//                        maxY = qMax( curdp.value, m_boundary.second.y() );
+//                    }
+//                }
+//                break;
+//            case ( PlotterDiagramCompressor::DISTANCE ):
+//                {
+//                    if ( predecessor.distance( curdp ) > m_mergeRadius && check )
+//                    {
+//                        if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].append( curdp );
+//                        }
+//                        else if ( !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].insert( row, curdp );
+//                        }
+//                        predecessor = curdp;
+//                        minX = qMin( curdp.key, m_boundary.first.x() );
+//                        minY = qMin( curdp.value, m_boundary.first.y() );
+//                        maxX = qMax( curdp.key, m_boundary.second.x() );
+//                        maxY = qMax( curdp.value, m_boundary.second.y() );
+//                    }
+//                }
+//                break;
+//            case( PlotterDiagramCompressor::SLOPE ):
+//                {
+//                    if ( check && qAbs( newSlope - oldSlope ) >= m_maxSlopeRadius )
+//                    {
+//                        if ( start > m_bufferlist[ dataset ].count() && !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].append( curdp );
+//                            oldSlope = newSlope;
+//                        }
+//                        else if ( !m_bufferlist[ dataset ].isEmpty() )
+//                        {
+//                            m_bufferlist[ dataset ].insert( row, curdp );
+//                            oldSlope = newSlope;
+//                        }
 
-                       predecessor = curdp;
-                       minX = qMin( curdp.key, m_boundary.first.x() );
-                       minY = qMin( curdp.value, m_boundary.first.y() );
-                       maxX = qMax( curdp.key, m_boundary.second.x() );
-                       maxY = qMax( curdp.value, m_boundary.second.y() );
+//                        predecessor = curdp;
+//                        minX = qMin( curdp.key, m_boundary.first.x() );
+//                        minY = qMin( curdp.value, m_boundary.first.y() );
+//                        maxX = qMax( curdp.key, m_boundary.second.x() );
+//                        maxY = qMax( curdp.value, m_boundary.second.y() );
 
-                       if ( first )
-                       {
-                           oldSlope = newSlope;
-                           first = false;
-                       }
-                       olddp = newdp;
-                       newdp = m_parent->data( CachePosition( row, dataset ) );
-                       newSlope = calculateSlope( olddp, newdp );
-                   }
-               }
-               break;
-           }
-       }
-   }
-   setBoundaries( qMakePair( QPointF( minX, minY ), QPointF( maxX, maxY ) ) );
-   Q_EMIT m_parent->rowCountChanged();
-}
-#endif
+//                        if ( first )
+//                        {
+//                            oldSlope = newSlope;
+//                            first = false;
+//                        }
+//                        olddp = newdp;
+//                        newdp = m_parent->data( CachePosition( row, dataset ) );
+//                        newSlope = calculateSlope( olddp, newdp );
+//                    }
+//                }
+//                break;
+//            }
+//        }
+//    }
+//    setBoundaries( qMakePair( QPointF( minX, minY ), QPointF( maxX, maxY ) ) );
+//    emit m_parent->rowCountChanged();
+//}
 #include <QDebug>
 // TODO this is not threadsafe do never try to invoke the painting in a different thread than this
 // method
@@ -690,7 +688,7 @@ void PlotterDiagramCompressor::Private::rowsInserted( const QModelIndex& /*paren
         }
         }
     }
-    Q_EMIT m_parent->rowCountChanged();
+    emit m_parent->rowCountChanged();
 }
 
 
@@ -701,7 +699,7 @@ void PlotterDiagramCompressor::setCompressionModel( CompressionMode value )
     {
         d->m_mode = value;
         d->clearBuffer();
-        Q_EMIT rowCountChanged();
+        emit rowCountChanged();
     }
 }
 
@@ -710,7 +708,7 @@ void PlotterDiagramCompressor::Private::setBoundaries( const Boundaries & bound
     if ( bound != m_boundary )
     {
         m_boundary = bound;
-        Q_EMIT m_parent->boundariesChanged();
+        emit m_parent->boundariesChanged();
     }
 }
 
@@ -793,7 +791,7 @@ PlotterDiagramCompressor::PlotterDiagramCompressor(QObject *parent)
 PlotterDiagramCompressor::~PlotterDiagramCompressor()
 {
     delete d;
-    d = nullptr;
+    d = 0;
 }
 
 void PlotterDiagramCompressor::setForcedDataBoundaries( const QPair< qreal, qreal > &bounds, Qt::Orientation direction )
@@ -807,7 +805,7 @@ void PlotterDiagramCompressor::setForcedDataBoundaries( const QPair< qreal, qrea
         d->m_forcedXBoundaries = bounds;
     }
     d->clearBuffer();
-    Q_EMIT boundariesChanged();
+    emit boundariesChanged();
 }
 
 QAbstractItemModel* PlotterDiagramCompressor::model() const
@@ -830,9 +828,9 @@ void PlotterDiagramCompressor::setModel( QAbstractItemModel *model )
         d->m_bufferlist.resize( datasetCount() );
         d->m_accumulatedDistances.resize( datasetCount() );
         d->calculateDataBoundaries();
-        connect( d->m_model, SIGNAL(rowsInserted(QModelIndex,int,int)), d, SLOT(rowsInserted(QModelIndex,int,int)) );
-        connect( d->m_model, SIGNAL(modelReset()), d, SLOT(clearBuffer()) );
-        connect( d->m_model, SIGNAL(destroyed(QObject*)), d, SLOT(setModelToZero()) );
+        connect( d->m_model, SIGNAL( rowsInserted ( QModelIndex, int, int ) ), d, SLOT( rowsInserted( QModelIndex, int, int ) ) );
+        connect( d->m_model, SIGNAL( modelReset() ), d, SLOT( clearBuffer() ) );
+        connect( d->m_model, SIGNAL( destroyed( QObject* ) ), d, SLOT( setModelToZero() ) );
     }
 }
 
@@ -861,7 +859,7 @@ void PlotterDiagramCompressor::setMergeRadius( qreal radius )
     {
         d->m_mergeRadius = radius;
         if ( d->m_mode != PlotterDiagramCompressor::SLOPE )
-            Q_EMIT rowCountChanged();
+            emit rowCountChanged();
     }
 }
 
@@ -870,7 +868,7 @@ void PlotterDiagramCompressor::setMaxSlopeChange( qreal value )
     if ( d->m_maxSlopeRadius != value )
     {
         d->m_maxSlopeRadius = value;
-        Q_EMIT boundariesChanged();
+        emit boundariesChanged();
     }
 }
 
