@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -23,7 +23,7 @@
 
 using namespace KChart;
 
-class StockBarAttributes::Private {
+class Q_DECL_HIDDEN StockBarAttributes::Private {
 public:
     Private();
 
