@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -42,7 +42,7 @@ namespace KChart {
 /**
  * \internal
  */
-class ThreeDBarAttributes::Private : public AbstractThreeDAttributes::Private
+class Q_DECL_HIDDEN ThreeDBarAttributes::Private : public AbstractThreeDAttributes::Private
 {
     friend class ThreeDBarAttributes;
 public:
