@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -47,7 +47,7 @@ namespace KChart {
 /**
  * \internal
  */
-    class AbstractAreaBase::Private
+    class Q_DECL_HIDDEN AbstractAreaBase::Private
     {
         friend class AbstractAreaBase;
     public:
