@@ -14,7 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <https://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include "KChartAbstractDiagram.h"
@@ -26,7 +26,6 @@
 #include <QApplication>
 #include <QAbstractProxyModel>
 #include <QSizeF>
-#include <QPainterPath>
 
 #include "KChartAbstractCoordinatePlane.h"
 #include "KChartChart.h"
@@ -52,7 +51,7 @@ AbstractDiagram::AbstractDiagram ( QWidget* parent, AbstractCoordinatePlane* pla
 
 AbstractDiagram::~AbstractDiagram()
 {
-    Q_EMIT aboutToBeDestroyed();
+    emit aboutToBeDestroyed();
     delete _d;
 }
 
@@ -145,26 +144,26 @@ void AbstractDiagram::setModel( QAbstractItemModel * newModel )
 
     scheduleDelayedItemsLayout();
     setDataBoundariesDirty();
-    Q_EMIT modelsChanged();
+    emit modelsChanged();
 }
 
 void AbstractDiagram::setSelectionModel( QItemSelectionModel* newSelectionModel )
 {
     if ( selectionModel() )
     {
-        disconnect( selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SIGNAL(modelsChanged()) );
-        disconnect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SIGNAL(modelsChanged()) );
+        disconnect( selectionModel(), SIGNAL( currentChanged( QModelIndex, QModelIndex ) ), this, SIGNAL( modelsChanged() ) );
+        disconnect( selectionModel(), SIGNAL( selectionChanged( QItemSelection, QItemSelection ) ), this, SIGNAL( modelsChanged() ) );
     }
     QAbstractItemView::setSelectionModel( newSelectionModel );
     if ( selectionModel() )
     {
-        connect( selectionModel(), SIGNAL(currentChanged(QModelIndex,QModelIndex)), this, SIGNAL(modelsChanged()) );
-        connect( selectionModel(), SIGNAL(selectionChanged(QItemSelection,QItemSelection)), this, SIGNAL(modelsChanged()) );
+        connect( selectionModel(), SIGNAL( currentChanged( QModelIndex, QModelIndex ) ), this, SIGNAL( modelsChanged() ) );
+        connect( selectionModel(), SIGNAL( selectionChanged( QItemSelection, QItemSelection ) ), this, SIGNAL( modelsChanged() ) );
     }
-    Q_EMIT modelsChanged();
+    emit modelsChanged();
 }
 
-/* Sets an external AttributesModel on this diagram. By default, a diagram has it's
+/*! Sets an external AttributesModel on this diagram. By default, a diagram has it's
   own internal set of attributes, but an external one can be set. This can be used to
   share attributes between several diagrams. The diagram does not take ownership of the
   attributesmodel.
@@ -188,7 +187,7 @@ void AbstractDiagram::setAttributesModel( AttributesModel* amodel )
     d->setAttributesModel( amodel );
     scheduleDelayedItemsLayout();
     setDataBoundariesDirty();
-    Q_EMIT modelsChanged();
+    emit modelsChanged();
 }
 
 bool AbstractDiagram::usesExternalAttributesModel() const
@@ -207,13 +206,14 @@ QModelIndex AbstractDiagram::conditionallyMapFromSource( const QModelIndex & ind
     return index.model() == attributesModel() ? index : attributesModel()->mapFromSource( index );
 }
 
-/* \reimpl */
-void AbstractDiagram::setRootIndex( const QModelIndex& idx )
+/*! \reimpl */
+void AbstractDiagram::setRootIndex ( const QModelIndex& idx )
 {
     QAbstractItemView::setRootIndex( idx );
     setAttributesModelRootIndex( d->attributesModel->mapFromSource( idx ) );
 }
 
+/*! \internal */
 void AbstractDiagram::setAttributesModelRootIndex( const QModelIndex& idx )
 {
     d->attributesModelRootIndex = idx;
@@ -221,6 +221,8 @@ void AbstractDiagram::setAttributesModelRootIndex( const QModelIndex& idx )
     scheduleDelayedItemsLayout();
 }
 
+/*! returns a QModelIndex pointing into the AttributesModel that corresponds to the
+  root index of the diagram. */
 QModelIndex AbstractDiagram::attributesModelRootIndex() const
 {
     if ( !d->attributesModelRootIndex.isValid() )
@@ -258,21 +260,21 @@ void AbstractDiagram::setHidden( const QModelIndex & index, bool hidden )
 {
     d->attributesModel->setData(
         conditionallyMapFromSource( index ),
-        QVariant::fromValue( hidden ),
+        qVariantFromValue( hidden ),
         DataHiddenRole );
-    Q_EMIT dataHidden();
+    emit dataHidden();
 }
 
 void AbstractDiagram::setHidden( int dataset, bool hidden )
 {
-    d->setDatasetAttrs( dataset, QVariant::fromValue( hidden ), DataHiddenRole );
-    Q_EMIT dataHidden();
+    d->setDatasetAttrs( dataset, qVariantFromValue( hidden ), DataHiddenRole );
+    emit dataHidden();
 }
 
 void AbstractDiagram::setHidden( bool hidden )
 {
-    d->attributesModel->setModelData( QVariant::fromValue( hidden ), DataHiddenRole );
-    Q_EMIT dataHidden();
+    d->attributesModel->setModelData( qVariantFromValue( hidden ), DataHiddenRole );
+    emit dataHidden();
 }
 
 bool AbstractDiagram::isHidden() const
@@ -303,16 +305,16 @@ bool AbstractDiagram::isHidden( const QModelIndex & index ) const
 void AbstractDiagram::setDataValueAttributes( const QModelIndex & index,
                                               const DataValueAttributes & a )
 {
-    d->attributesModel->setData( conditionallyMapFromSource( index ), QVariant::fromValue( a ),
+    d->attributesModel->setData( conditionallyMapFromSource( index ), qVariantFromValue( a ),
                                  DataValueLabelAttributesRole );
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 
 void AbstractDiagram::setDataValueAttributes( int dataset, const DataValueAttributes & a )
 {
-    d->setDatasetAttrs( dataset, QVariant::fromValue( a ), DataValueLabelAttributesRole );
-    Q_EMIT propertiesChanged();
+    d->setDatasetAttrs( dataset, qVariantFromValue( a ), DataValueLabelAttributesRole );
+    emit propertiesChanged();
 }
 
 DataValueAttributes AbstractDiagram::dataValueAttributes() const
@@ -349,8 +351,8 @@ DataValueAttributes AbstractDiagram::dataValueAttributes( const QModelIndex & in
 
 void AbstractDiagram::setDataValueAttributes( const DataValueAttributes & a )
 {
-    d->attributesModel->setModelData( QVariant::fromValue( a ), DataValueLabelAttributesRole );
-    Q_EMIT propertiesChanged();
+    d->attributesModel->setModelData( qVariantFromValue( a ), DataValueLabelAttributesRole );
+    emit propertiesChanged();
 }
 
 void AbstractDiagram::setAllowOverlappingDataValueTexts( bool allow )
@@ -359,7 +361,7 @@ void AbstractDiagram::setAllowOverlappingDataValueTexts( bool allow )
     attrs.setShowOverlappingDataLabels( allow );
     setDataValueAttributes( attrs );
     d->allowOverlappingDataValueTexts = allow;
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool AbstractDiagram::allowOverlappingDataValueTexts() const
@@ -370,7 +372,7 @@ bool AbstractDiagram::allowOverlappingDataValueTexts() const
 void AbstractDiagram::setAntiAliasing( bool enabled )
 {
     d->antiAliasing = enabled;
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool AbstractDiagram::antiAliasing() const
@@ -381,7 +383,7 @@ bool AbstractDiagram::antiAliasing() const
 void AbstractDiagram::setPercentMode ( bool percent )
 {
     d->percent = percent;
-    Q_EMIT propertiesChanged();
+    emit propertiesChanged();
 }
 
 bool AbstractDiagram::percentMode() const
@@ -492,7 +494,7 @@ void AbstractDiagram::paintMarker( QPainter* painter,
     const bool isFourPixels = (markerAttributes.markerStyle() == MarkerAttributes::Marker4Pixels);
     if ( isFourPixels || (markerAttributes.markerStyle() == MarkerAttributes::Marker1Pixel) ) {
         // for high-performance point charts with tiny point markers:
-        painter->setPen( PrintingParameters::scalePen( QPen( brush.color().lighter() ) ) );
+        painter->setPen( PrintingParameters::scalePen( QPen( brush.color().light() ) ) );
         if ( isFourPixels ) {
             const qreal x = pos.x();
             const qreal y = pos.y();
@@ -829,21 +831,21 @@ void AbstractDiagram::setPen( const QModelIndex& index, const QPen& pen )
 {
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
-        QVariant::fromValue( pen ), DatasetPenRole );
-    Q_EMIT propertiesChanged();
+        qVariantFromValue( pen ), DatasetPenRole );
+    emit propertiesChanged();
 }
 
 void AbstractDiagram::setPen( const QPen& pen )
 {
     attributesModel()->setModelData(
-        QVariant::fromValue( pen ), DatasetPenRole );
-    Q_EMIT propertiesChanged();
+        qVariantFromValue( pen ), DatasetPenRole );
+    emit propertiesChanged();
 }
 
 void AbstractDiagram::setPen( int dataset, const QPen& pen )
 {
-    d->setDatasetAttrs( dataset, QVariant::fromValue( pen ), DatasetPenRole );
-    Q_EMIT propertiesChanged();
+    d->setDatasetAttrs( dataset, qVariantFromValue( pen ), DatasetPenRole );
+    emit propertiesChanged();
 }
 
 QPen AbstractDiagram::pen() const
@@ -870,21 +872,21 @@ void AbstractDiagram::setBrush( const QModelIndex& index, const QBrush& brush )
 {
     attributesModel()->setData(
         conditionallyMapFromSource( index ),
-        QVariant::fromValue( brush ), DatasetBrushRole );
-    Q_EMIT propertiesChanged();
+        qVariantFromValue( brush ), DatasetBrushRole );
+    emit propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( const QBrush& brush )
 {
     attributesModel()->setModelData(
-        QVariant::fromValue( brush ), DatasetBrushRole );
-    Q_EMIT propertiesChanged();
+        qVariantFromValue( brush ), DatasetBrushRole );
+    emit propertiesChanged();
 }
 
 void AbstractDiagram::setBrush( int dataset, const QBrush& brush )
 {
-    d->setDatasetAttrs( dataset, QVariant::fromValue( brush ), DatasetBrushRole );
-    Q_EMIT propertiesChanged();
+    d->setDatasetAttrs( dataset, qVariantFromValue( brush ), DatasetBrushRole );
+    emit propertiesChanged();
 }
 
 QBrush AbstractDiagram::brush() const
@@ -906,7 +908,7 @@ QBrush AbstractDiagram::brush( const QModelIndex& index ) const
         attributesModel()->data( conditionallyMapFromSource( index ), DatasetBrushRole ).value< QBrush >();
 }
 
-/*
+/**
   * Sets the unit prefix for one value
   * @param prefix the prefix to be set
   * @param column the value using that prefix
@@ -917,7 +919,7 @@ void AbstractDiagram::setUnitPrefix( const QString& prefix, int column, Qt::Orie
     d->unitPrefixMap[ column ][ orientation ]= prefix;
 }
 
-/*
+/**
   * Sets the unit prefix for all values
   * @param prefix the prefix to be set
   * @param orientation the orientantion of the axis to set
@@ -927,7 +929,7 @@ void AbstractDiagram::setUnitPrefix( const QString& prefix, Qt::Orientation orie
     d->unitPrefix[ orientation ] = prefix;
 }
 
-/*
+/**
   * Sets the unit suffix for one value
   * @param suffix the suffix to be set
   * @param column the value using that suffix
@@ -938,7 +940,7 @@ void AbstractDiagram::setUnitSuffix( const QString& suffix, int column, Qt::Orie
     d->unitSuffixMap[ column ][ orientation ]= suffix;
 }
 
-/*
+/**
   * Sets the unit suffix for all values
   * @param suffix the suffix to be set
   * @param orientation the orientantion of the axis to set
@@ -948,7 +950,7 @@ void AbstractDiagram::setUnitSuffix( const QString& suffix, Qt::Orientation orie
     d->unitSuffix[ orientation ] = suffix;
 }
 
-/*
+/**
   * Returns the unit prefix for a special value
   * @param column the value which's prefix is requested
   * @param orientation the orientation of the axis
@@ -962,7 +964,7 @@ QString AbstractDiagram::unitPrefix( int column, Qt::Orientation orientation, bo
     return d->unitPrefix[ orientation ];
 }
 
-/* Returns the global unit prefix
+/** Returns the global unit prefix
   * @param orientation the orientation of the axis
   * @return the unit prefix
   */
@@ -971,7 +973,7 @@ QString AbstractDiagram::unitPrefix( Qt::Orientation orientation ) const
     return d->unitPrefix[ orientation ];
 }
 
-/*
+/**
   * Returns the unit suffix for a special value
   * @param column the value which's suffix is requested
   * @param orientation the orientation of the axis
@@ -985,7 +987,7 @@ QString AbstractDiagram::unitSuffix( int column, Qt::Orientation orientation, bo
     return d->unitSuffix[ orientation ];
 }
 
-/* Returns the global unit suffix
+/** Returns the global unit suffix
   * @param orientation the orientation of the axis
   * @return the unit siffix
   */
@@ -1021,7 +1023,7 @@ void AbstractDiagram::setSelection(const QRect& rect , QItemSelectionModel::Sele
 {
     const QModelIndexList indexes = d->indexesIn( rect );
     QItemSelection selection;
-    for ( const QModelIndex& index : indexes )
+    Q_FOREACH( const QModelIndex& index, indexes )
     {
         selection.append( QItemSelectionRange( index ) );
     }
@@ -1031,9 +1033,7 @@ void AbstractDiagram::setSelection(const QRect& rect , QItemSelectionModel::Sele
 QRegion AbstractDiagram::visualRegionForSelection(const QItemSelection &selection) const
 {
     QPolygonF polygon;
-    const auto indexes = selection.indexes();
-    polygon.reserve(indexes.count());
-    for ( const QModelIndex& index : indexes )
+    Q_FOREACH( const QModelIndex& index, selection.indexes() )
     {
         polygon << d->reverseMapper.polygon(index.row(), index.column());
     }
@@ -1162,7 +1162,7 @@ void AbstractDiagram::setDatasetDimensionInternal( int dimension )
     d->datasetDimension = dimension;
     d->attributesModel->setDatasetDimension( dimension );
     setDataBoundariesDirty();
-    Q_EMIT layoutChanged( this );
+    emit layoutChanged( this );
 }
 
 qreal AbstractDiagram::valueForCell( int row, int column ) const
