@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -49,7 +49,7 @@ namespace KChart {
 /**
  * \internal
  */
-class KChart::HeaderFooter::Private : public KChart::TextArea::Private
+class Q_DECL_HIDDEN KChart::HeaderFooter::Private : public KChart::TextArea::Private
 {
     friend class KChart::HeaderFooter;
 public:
