@@ -22,7 +22,7 @@
 using namespace KChart;
 
 PrintingParameters::PrintingParameters()
-    : scaleFactor( 1.0 )
+    : m_scaleFactor( 1.0 )
 {
 }
 
@@ -32,25 +32,30 @@ PrintingParameters* PrintingParameters::instance()
     return &instance;
 }
 
+qreal PrintingParameters::scaleFactor()
+{
+    return instance()->m_scaleFactor;
+}
+
 void PrintingParameters::setScaleFactor( const qreal scaleFactor )
 {
-    instance()->scaleFactor = scaleFactor;
+    instance()->m_scaleFactor = scaleFactor;
 }
 
 void PrintingParameters::resetScaleFactor()
 {
-    instance()->scaleFactor = 1.0;
+    instance()->m_scaleFactor = 1.0;
 }
 
 QPen PrintingParameters::scalePen( const QPen& pen )
 {
-    if ( instance()->scaleFactor == 1.0 )
+    if ( instance()->m_scaleFactor == 1.0 )
         return pen;
 
     QPen resultPen = pen;
-    resultPen.setWidthF( resultPen.widthF() * instance()->scaleFactor );
+    resultPen.setWidthF( resultPen.widthF() * instance()->m_scaleFactor );
     if ( resultPen.widthF() == 0.0 )
-        resultPen.setWidthF( instance()->scaleFactor );
+        resultPen.setWidthF( instance()->m_scaleFactor );
 
     return resultPen;
 }
