@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -45,7 +45,7 @@ namespace KChart {
 /**
  * \internal
  */
-    class TextArea::Private : public AbstractAreaBase::Private
+    class Q_DECL_HIDDEN TextArea::Private : public AbstractAreaBase::Private
     {
         friend class TextArea;
     public:
