@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -44,7 +44,7 @@ class PolarCoordinatePlane;
 /**
  * \internal
  */
-class AbstractPieDiagram::Private : public AbstractPolarDiagram::Private
+class Q_DECL_HIDDEN AbstractPieDiagram::Private : public AbstractPolarDiagram::Private
 {
     friend class AbstractPieDiagram;
 public:
