@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -41,7 +41,7 @@ namespace KChart {
 /**
  * \internal
  */
-class PieDiagram::Private : public AbstractPieDiagram::Private
+class Q_DECL_HIDDEN PieDiagram::Private : public AbstractPieDiagram::Private
 {
     friend class PieDiagram;
 public:
