@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KD Chart library.
@@ -44,11 +44,11 @@ namespace KChart {
         PolarGrid() : AbstractGrid() {}
         virtual ~PolarGrid() {}
 
-        virtual void drawGrid( PaintContext* context );
+        void drawGrid( PaintContext* context ) Q_DECL_OVERRIDE;
 
     private:
-        virtual DataDimensionsList calculateGrid(
-            const DataDimensionsList& rawDataDimensions ) const;
+        DataDimensionsList calculateGrid(
+            const DataDimensionsList& rawDataDimensions ) const Q_DECL_OVERRIDE;
     };
 
 }
