@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -27,7 +27,7 @@
 #include "kganttabstractgrid.h"
 
 namespace KGantt {
-    class AbstractGrid::Private {
+    class Q_DECL_HIDDEN AbstractGrid::Private {
     public:
         QPointer<QAbstractItemModel> model;
         QPersistentModelIndex root;
