@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -31,7 +31,7 @@
 #include "kganttdatetimegrid.h"
 
 namespace KGantt {
-    class GraphicsScene::Private {
+    class Q_DECL_HIDDEN GraphicsScene::Private {
     public:
         explicit Private(GraphicsScene*);
 
