@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -265,17 +265,31 @@ void GraphicsView::Private::slotRowsInserted( const QModelIndex& parent,  int st
     q->updateScene(); // TODO: This might be optimised
 }
 
+void GraphicsView::Private::removeConstraintsRecursive( QAbstractProxyModel *summaryModel, const QModelIndex& index )
+{
+    if ( summaryModel->hasChildren( index ) ) {
+        //qDebug() << "removing constraints from children of"<<index;
+        for ( int row = 0; row < summaryModel->rowCount( index ); ++row ) {
+            const QModelIndex child = summaryModel->index( row, index.column(), index );
+            removeConstraintsRecursive( summaryModel, child );
+        }
+    }
+    //qDebug() << "removing constraints from"<<index;
+    // NOTE: Constraints are mapped to indexes in the summaryModel->sourceModel()
+    QList<Constraint> clst = scene.constraintModel()->constraintsForIndex( summaryModel->mapToSource( index ) );
+    Q_FOREACH( Constraint c, clst ) {
+        scene.constraintModel()->removeConstraint( c );
+    }
+}
+
 void GraphicsView::Private::slotRowsAboutToBeRemoved( const QModelIndex& parent,  int start, int end )
 {
     //qDebug() << "GraphicsView::Private::slotRowsAboutToBeRemoved("<<parent<<start<<end<<")";
+    QAbstractProxyModel *summaryModel = scene.summaryHandlingModel();
     for ( int row = start; row <= end; ++row ) {
-        for ( int col = 0; col < scene.summaryHandlingModel()->columnCount( parent ); ++col ) {
-            //qDebug() << "removing "<<scene.summaryHandlingModel()->index( row, col, parent );
-            const QModelIndex idx = scene.summaryHandlingModel()->index( row, col, parent );
-            QList<Constraint> clst = scene.constraintModel()->constraintsForIndex( idx );
-            Q_FOREACH( Constraint c, clst ) {
-                scene.constraintModel()->removeConstraint( c );
-            }
+        for ( int col = 0; col < summaryModel->columnCount( parent ); ++col ) {
+            const QModelIndex idx = summaryModel->index( row, col, parent );
+            removeConstraintsRecursive( summaryModel, idx );
             scene.removeItem( idx );
         }
     }
@@ -389,6 +403,10 @@ GraphicsView::~GraphicsView()
  * GraphicsView operates per row in the model. The data is always
  * taken from the _last_ item in the row. The ItemRoles used are
  * Qt::DisplayRole and the roles defined in KGantt::ItemDataRole.
+ * 
+ * Note: This model is not returned by \a model()
+ * 
+ * \see GraphicsView::model
  */
 void GraphicsView::setModel( QAbstractItemModel* model )
 {
@@ -403,6 +421,10 @@ void GraphicsView::setModel( QAbstractItemModel* model )
 }
 
 /*! \returns the current model displayed by this view
+ * 
+ * Note: The returned model is not the model set with \a setModel()
+ * 
+ * \see GraphicsView::setModel
  */
 QAbstractItemModel* GraphicsView::model() const
 {
