@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -25,7 +25,7 @@
 #include "kganttproxymodel.h"
 
 namespace KGantt {
-    class Legend::Private {
+    class Q_DECL_HIDDEN Legend::Private {
     public:
         ProxyModel proxyModel;
     };
