@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -29,7 +29,7 @@ class QAbstractProxyModel;
 QT_END_NAMESPACE
 
 namespace KGantt {
-    class TreeViewRowController::Private {
+    class Q_DECL_HIDDEN TreeViewRowController::Private {
     public:
         class HackTreeView : public QTreeView {
         public:
