@@ -1,4 +1,4 @@
-/**
+/*
  * Copyright (C) 2001-2015 Klaralvdalens Datakonsult AB.  All rights reserved.
  *
  * This file is part of the KGantt library.
@@ -48,7 +48,7 @@ namespace {
         explicit HeaderView( QWidget* parent=0 ) : QHeaderView( Qt::Horizontal, parent ) {
         }
 
-        QSize sizeHint() const { QSize s = QHeaderView::sizeHint(); s.rheight() *= 2; return s; }
+        QSize sizeHint() const Q_DECL_OVERRIDE { QSize s = QHeaderView::sizeHint(); s.rheight() *= 2; return s; }
     };
 }
 
@@ -216,8 +216,11 @@ void View::Private::slotVerticalScrollValueChanged( int val )
 void View::Private::slotLeftWidgetVerticalRangeChanged(int min, int max )
 {
     //qDebug() << "View::Private::slotLeftWidgetVerticalRangeChanged("<<min<<max<<")";
-    gfxview->verticalScrollBar()->setRange( min, max );
-    gfxview->updateSceneRect();
+    // In some cases the gfxview has already been deleted when this signal arrive
+    if (!gfxview.isNull()) {
+        gfxview->verticalScrollBar()->setRange( min, max );
+        gfxview->updateSceneRect();
+    }
 }
 
 void View::Private::slotGfxViewVerticalRangeChanged( int min, int max )
@@ -353,6 +356,7 @@ void View::setGraphicsView( GraphicsView* gv )
     if ( gv != d->gfxview ) {
         GraphicsView* old = d->gfxview;
         d->gfxview = gv;
+        d->gfxview->setModel(old->model()); // use the old ForwardingProxyModel
         d->setupGraphicsView();
         d->gfxview->setGrid( old->grid() );
         delete old;
@@ -439,14 +443,24 @@ void View::setGrid( AbstractGrid* grid )
 
 void View::expandAll( QModelIndex index )
 {
+    // FIXME:
+    // It is legal to call setLeftView() with any QAbstractItemView,
+    // so expandAll should be reimplemented to work with that.
     KGanttTreeView* tw = qobject_cast<KGanttTreeView*>(leftView());
-    tw->expandAll(index);
+    if (tw) {
+        tw->expandAll(index);
+    }
 }
 
 void View::collapseAll( QModelIndex index )
 {
+    // FIXME:
+    // It is legal to call setLeftView() with any QAbstractItemView,
+    // so expandAll should be reimplemented to work with that.
     KGanttTreeView* tw = qobject_cast<KGanttTreeView*>(leftView());
-    tw->collapseAll(index);
+    if (tw) {
+        tw->collapseAll(index);
+    }
 }
 
 /*! \returns the AbstractGrid used by this view.
